@@ -11,6 +11,9 @@
 #include "formatting.h"
 #include "kleo/dn.h"
 #include "kleo/keyfiltermanager.h"
+#include "kleo/keygroup.h"
+
+#include "utils/compat.h"
 
 #include <gpgme++/key.h>
 #include <gpgme++/importresult.h>
@@ -443,6 +446,75 @@ QString Formatting::toolTip(const Key &key, int flags)
     return result;
 }
 
+namespace
+{
+template <typename Container>
+QString getValidityStatement(const Container &keys)
+{
+    const bool allKeysAreOpenPGP = std::all_of(keys.cbegin(), keys.cend(), [] (const Key &key) { return key.protocol() == OpenPGP; });
+    const bool allKeysAreValidated = std::all_of(keys.cbegin(), keys.cend(), [] (const Key &key) { return key.keyListMode() & Validate; });
+    if (allKeysAreOpenPGP || allKeysAreValidated) {
+        const bool someKeysAreBad = std::any_of(keys.cbegin(), keys.cend(), std::mem_fn(&Key::isBad));
+        if (someKeysAreBad) {
+            return i18n("Some keys are revoked, expired, disabled, or invalid.");
+        } else {
+            const bool allKeysAreFullyValid = std::all_of(keys.cbegin(), keys.cend(), &Formatting::uidsHaveFullValidity);
+            if (allKeysAreFullyValid) {
+                return i18n("All keys are certified.");
+            } else {
+                return i18n("Some keys are not certified.");
+            }
+        }
+    }
+    return i18n("The validity of the keys cannot be checked at the moment.");
+}
+}
+
+QString Formatting::toolTip(const KeyGroup &group, int flags)
+{
+    static const unsigned int maxNumKeysForTooltip = 20;
+
+    if (group.isNull()) {
+        return QString();
+    }
+
+    const KeyGroup::Keys &keys = group.keys();
+    if (keys.size() == 0) {
+        return i18nc("@info:tooltip", "This group does not contain any keys.");
+    }
+
+    const QString validity = (flags & Validity) ? getValidityStatement(keys) : QString();
+    if (flags == Validity) {
+        return validity;
+    }
+
+    // list either up to maxNumKeysForTooltip keys or (maxNumKeysForTooltip-1) keys followed by "and n more keys"
+    const unsigned int numKeysForTooltip = keys.size() > maxNumKeysForTooltip ? maxNumKeysForTooltip - 1 : keys.size();
+
+    QStringList result;
+    result.reserve(3 + 2 + numKeysForTooltip + 2);
+    if (!validity.isEmpty()) {
+        result.push_back("<p>");
+        result.push_back(validity.toHtmlEscaped());
+        result.push_back("</p>");
+    }
+
+    result.push_back("<p>");
+    result.push_back(i18n("Keys:"));
+    {
+        auto it = keys.cbegin();
+        for (unsigned int i = 0; i < numKeysForTooltip; ++i, ++it) {
+            result.push_back(QLatin1String("<br>") + Formatting::summaryLine(*it).toHtmlEscaped());
+        }
+    }
+    if (keys.size() > numKeysForTooltip) {
+        result.push_back(QLatin1String("<br>") + i18ncp("this follows a list of keys", "and 1 more key", "and %1 more keys", keys.size() - numKeysForTooltip));
+    }
+    result.push_back("</p>");
+
+    return result.join(QLatin1Char('\n'));
+}
+
 //
 // Creation and Expiration
 //
@@ -570,6 +642,12 @@ QString Formatting::type(const Subkey &subkey)
     return QString::fromUtf8(subkey.publicKeyAlgorithmAsString());
 }
 
+QString Formatting::type(const KeyGroup &group)
+{
+    Q_UNUSED(group)
+    return i18nc("a group of keys/certificates", "Group");
+}
+
 //
 // Status / Validity
 //
@@ -889,10 +967,30 @@ QString Formatting::summaryLine(const Key &key)
                  Formatting::creationDateString(key));
 }
 
-// Icon for certificate selection indication
-QIcon Formatting::iconForUid(const UserID &uid)
+QString Formatting::summaryLine(const KeyGroup &group)
 {
-    switch (uid.validity()) {
+    switch (group.source()) {
+        case KeyGroup::ApplicationConfig:
+        case KeyGroup::GnuPGConfig:
+            return i18ncp("name of group of keys (n key(s), validity)",
+                          "%2 (1 key, %3)", "%2 (%1 keys, %3)",
+                          group.keys().size(), group.name(), Formatting::complianceStringShort(group));
+        case KeyGroup::Tags:
+            return i18ncp("name of group of keys (n key(s), validity, tag)",
+                          "%2 (1 key, %3, tag)", "%2 (%1 keys, %3, tag)",
+                          group.keys().size(), group.name(), Formatting::complianceStringShort(group));
+        default:
+            return i18ncp("name of group of keys (n key(s), validity, group ...)",
+                          "%2 (1 key, %3, unknown origin)", "%2 (%1 keys, %3, unknown origin)",
+                          group.keys().size(), group.name(), Formatting::complianceStringShort(group));
+    }
+}
+
+namespace
+{
+QIcon iconForValidity(UserID::Validity validity)
+{
+    switch (validity) {
         case UserID::Ultimate:
         case UserID::Full:
         case UserID::Marginal:
@@ -905,6 +1003,13 @@ QIcon Formatting::iconForUid(const UserID &uid)
             return QIcon::fromTheme(QStringLiteral("emblem-information"));
     }
 }
+}
+
+// Icon for certificate selection indication
+QIcon Formatting::iconForUid(const UserID &uid)
+{
+    return iconForValidity(uid.validity());
+}
 
 QString Formatting::validity(const UserID &uid)
 {
@@ -924,23 +1029,52 @@ QString Formatting::validity(const UserID &uid)
     }
 }
 
-bool Formatting::uidsHaveFullValidity(const GpgME::Key &key)
+QString Formatting::validity(const KeyGroup &group)
 {
-    bool oneValid = false;
-    for (const auto &uid: key.userIDs()) {
-        if (uid.isRevoked()) {
-            /* Skip revoked uids */
-            continue;
-        }
-        if (uid.validity() < UserID::Validity::Full) {
-            return false;
-        }
-        /* Only return true if we have found at least one
-         * valid uid. E.g. if all uids are revoked we do
-         * not want to return true here. */
-        oneValid = true;
+    if (group.isNull()) {
+        return QString();
     }
-    return oneValid;
+
+    const KeyGroup::Keys &keys = group.keys();
+    if (keys.size() == 0) {
+        return i18n("This group does not contain any keys.");
+    }
+
+    return getValidityStatement(keys);
+}
+
+namespace
+{
+UserID::Validity minimalValidityOfNotRevokedUserIDs(const Key &key)
+{
+    std::vector<UserID> userIDs = key.userIDs();
+    const auto endOfNotRevokedUserIDs = std::remove_if(userIDs.begin(), userIDs.end(), std::mem_fn(&UserID::isRevoked));
+    const int minValidity = std::accumulate(userIDs.begin(), endOfNotRevokedUserIDs, UserID::Ultimate + 1,
+                                            [] (int validity, const UserID &userID) {
+                                                return std::min(validity, static_cast<int>(userID.validity()));
+                                            });
+    return minValidity <= UserID::Ultimate ? static_cast<UserID::Validity>(minValidity) : UserID::Unknown;
+}
+
+template <typename Container>
+UserID::Validity minimalValidity(const Container& keys)
+{
+    const int minValidity = std::accumulate(keys.cbegin(), keys.cend(), UserID::Ultimate + 1,
+                                            [] (int validity, const Key &key) {
+                                                return std::min<int>(validity, minimalValidityOfNotRevokedUserIDs(key));
+                                            });
+    return minValidity <= UserID::Ultimate ? static_cast<UserID::Validity>(minValidity) : UserID::Unknown;
+}
+}
+
+QIcon Formatting::validityIcon(const KeyGroup &group)
+{
+    return iconForValidity(minimalValidity(group.keys()));
+}
+
+bool Formatting::uidsHaveFullValidity(const Key &key)
+{
+    return minimalValidityOfNotRevokedUserIDs(key) >= UserID::Full;
 }
 
 QString Formatting::complianceMode()
@@ -949,8 +1083,7 @@ QString Formatting::complianceMode()
     if (!config) {
         return QString();
     }
-    const QGpgME::CryptoConfigEntry *const entry = config->entry(QStringLiteral("gpg"), QStringLiteral("Configuration"), QStringLiteral("compliance"));
-
+    const QGpgME::CryptoConfigEntry *const entry = getCryptoConfigEntry(config, "gpg", "compliance");
     if (!entry || entry->stringValue() == QLatin1String("gnupg")) {
         return QString();
     }
@@ -1012,6 +1145,18 @@ QString Formatting::complianceStringShort(const GpgME::Key &key)
     return i18nc("As in not all user IDs are valid.", "not certified");
 }
 
+QString Formatting::complianceStringShort(const KeyGroup &group)
+{
+    const KeyGroup::Keys &keys = group.keys();
+
+    const bool allKeysFullyValid = std::all_of(keys.cbegin(), keys.cend(), &Formatting::uidsHaveFullValidity);
+    if (allKeysFullyValid) {
+        return i18nc("As in all keys are valid.", "all certified");
+    }
+
+    return i18nc("As in not all keys are valid.", "not all certified");
+}
+
 QString Formatting::prettyID(const char *id)
 {
     if (!id) {
